import { scaleOrdinal } from 'd3';

const colorScale = scaleOrdinal()
		.domain(['apple', 'lemon'])
		.range(['#c11d1d', '#eae600']);

const radiusScale = scaleOrdinal()
		.domain(['apple', 'lemon'])
		.range(['50', '30']);

const xPosition = (d, i) => i*120 + 120;

export const fruitBowl = (selection, props) => {
  
  	const {fruits, 
           height, 
           onClick,
           selectedFruit
          } = props;
  
  	const bowl = selection.selectAll('rect')
    	.data([null])
    	.enter()
    		.append('rect')
    		.attr('width', 730)
    		.attr('height', 200)
    		.attr('y', 150)
    		.attr('rx', 100);
  
    const groups = selection.selectAll('g')
      	.data(fruits);
  	
  	const groupsEnter = groups.enter().append('g');
  
  	groupsEnter
  		.merge(groups)
  			.attr('transform', (d, i) => 
              `translate(${i*120 + 120}, ${height/2})`);
		groups.exit().remove();
  
  	groupsEnter.append('circle')
  		.merge(groups.select('circle'))
  			.attr('fill', d => colorScale(d.type))
  		  .attr('r', d => radiusScale(d.type))
  			.attr('stroke-width', 3)
  			.attr('stroke', d => d.id === selectedFruit 
             			? 'black'
             			: 'none')
  			.on('click', d =>	onClick(d.id));
  
    groupsEnter.append('text')
  		.merge(groups.select('text'))
  			.text(d => d.type)
  			.attr('y', 70); 
  	
};